# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import cost_graph_pb2 as tensorboard_dot_compat_dot_proto_dot_cost__graph__pb2
from tensorboard.compat.proto import graph_pb2 as tensorboard_dot_compat_dot_proto_dot_graph__pb2
from tensorboard.compat.proto import step_stats_pb2 as tensorboard_dot_compat_dot_proto_dot_step__stats__pb2
from tensorboard.compat.proto import cluster_pb2 as tensorboard_dot_compat_dot_proto_dot_cluster__pb2
from tensorboard.compat.proto import debug_pb2 as tensorboard_dot_compat_dot_proto_dot_debug__pb2
from tensorboard.compat.proto import rewriter_config_pb2 as tensorboard_dot_compat_dot_proto_dot_rewriter__config__pb2
from tensorboard.compat.proto import rpc_options_pb2 as tensorboard_dot_compat_dot_proto_dot_rpc__options__pb2
from tensorboard.compat.proto import coordination_config_pb2 as tensorboard_dot_compat_dot_proto_dot_coordination__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tensorboard/compat/proto/config.proto\x12\x0btensorboard\x1a)tensorboard/compat/proto/cost_graph.proto\x1a$tensorboard/compat/proto/graph.proto\x1a)tensorboard/compat/proto/step_stats.proto\x1a&tensorboard/compat/proto/cluster.proto\x1a$tensorboard/compat/proto/debug.proto\x1a.tensorboard/compat/proto/rewriter_config.proto\x1a*tensorboard/compat/proto/rpc_options.proto\x1a\x32tensorboard/compat/proto/coordination_config.proto\"\x8c\n\n\nGPUOptions\x12\'\n\x1fper_process_gpu_memory_fraction\x18\x01 \x01(\x01\x12\x14\n\x0c\x61llow_growth\x18\x04 \x01(\x08\x12\x16\n\x0e\x61llocator_type\x18\x02 \x01(\t\x12\x1f\n\x17\x64\x65\x66\x65rred_deletion_bytes\x18\x03 \x01(\x03\x12\x1b\n\x13visible_device_list\x18\x05 \x01(\t\x12\"\n\x1apolling_active_delay_usecs\x18\x06 \x01(\x05\x12$\n\x1cpolling_inactive_delay_msecs\x18\x07 \x01(\x05\x12\x1c\n\x14\x66orce_gpu_compatible\x18\x08 \x01(\x08\x12:\n\x0c\x65xperimental\x18\t \x01(\x0b\x32$.tensorboard.GPUOptions.Experimental\x1a\xc4\x07\n\x0c\x45xperimental\x12L\n\x0fvirtual_devices\x18\x01 \x03(\x0b\x32\x33.tensorboard.GPUOptions.Experimental.VirtualDevices\x12#\n\x1bnum_virtual_devices_per_gpu\x18\x0f \x01(\x05\x12\x1a\n\x12use_unified_memory\x18\x02 \x01(\x08\x12#\n\x1bnum_dev_to_dev_copy_streams\x18\x03 \x01(\x05\x12\x1d\n\x15\x63ollective_ring_order\x18\x04 \x01(\t\x12\x1d\n\x15timestamped_allocator\x18\x05 \x01(\x08\x12#\n\x1bkernel_tracker_max_interval\x18\x07 \x01(\x05\x12 \n\x18kernel_tracker_max_bytes\x18\x08 \x01(\x05\x12\"\n\x1akernel_tracker_max_pending\x18\t \x01(\x05\x12\'\n\x1finternal_fragmentation_fraction\x18\n \x01(\x01\x12\x1d\n\x15use_cuda_malloc_async\x18\x0b \x01(\x08\x12,\n$disallow_retry_on_allocation_failure\x18\x0c \x01(\x08\x12 \n\x18gpu_host_mem_limit_in_mb\x18\r \x01(\x02\x12$\n\x1cgpu_host_mem_disallow_growth\x18\x0e \x01(\x08\x12$\n\x1cgpu_system_memory_size_in_mb\x18\x10 \x01(\x05\x12.\n&populate_pjrt_gpu_client_creation_info\x18\x11 \x01(\x08\x12\x0f\n\x07node_id\x18\x12 \x01(\x05\x12U\n\x14stream_merge_options\x18\x13 \x01(\x0b\x32\x37.tensorboard.GPUOptions.Experimental.StreamMergeOptions\x1aS\n\x0eVirtualDevices\x12\x17\n\x0fmemory_limit_mb\x18\x01 \x03(\x02\x12\x10\n\x08priority\x18\x02 \x03(\x05\x12\x16\n\x0e\x64\x65vice_ordinal\x18\x03 \x03(\x05\x1a\x85\x01\n\x12StreamMergeOptions\x12#\n\x1bmerge_host_to_device_stream\x18\x01 \x01(\x08\x12#\n\x1bmerge_device_to_host_stream\x18\x02 \x01(\x08\x12%\n\x1dmerge_device_to_device_stream\x18\x03 \x01(\x08\"\x9f\x03\n\x10OptimizerOptions\x12+\n#do_common_subexpression_elimination\x18\x01 \x01(\x08\x12\x1b\n\x13\x64o_constant_folding\x18\x02 \x01(\x08\x12$\n\x1cmax_folded_constant_in_bytes\x18\x06 \x01(\x03\x12\x1c\n\x14\x64o_function_inlining\x18\x04 \x01(\x08\x12\x36\n\topt_level\x18\x03 \x01(\x0e\x32#.tensorboard.OptimizerOptions.Level\x12\x46\n\x10global_jit_level\x18\x05 \x01(\x0e\x32,.tensorboard.OptimizerOptions.GlobalJitLevel\x12\x16\n\x0e\x63pu_global_jit\x18\x07 \x01(\x08\" \n\x05Level\x12\x06\n\x02L1\x10\x00\x12\x0f\n\x02L0\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"C\n\x0eGlobalJitLevel\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x03OFF\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x08\n\x04ON_1\x10\x01\x12\x08\n\x04ON_2\x10\x02\"\xf0\x02\n\x0cGraphOptions\x12\x1e\n\x16\x65nable_recv_scheduling\x18\x02 \x01(\x08\x12\x38\n\x11optimizer_options\x18\x03 \x01(\x0b\x32\x1d.tensorboard.OptimizerOptions\x12\x18\n\x10\x62uild_cost_model\x18\x04 \x01(\x03\x12\x1e\n\x16\x62uild_cost_model_after\x18\t \x01(\x03\x12\x14\n\x0cinfer_shapes\x18\x05 \x01(\x08\x12\x1a\n\x12place_pruned_graph\x18\x06 \x01(\x08\x12 \n\x18\x65nable_bfloat16_sendrecv\x18\x07 \x01(\x08\x12\x15\n\rtimeline_step\x18\x08 \x01(\x05\x12\x34\n\x0frewrite_options\x18\n \x01(\x0b\x32\x1b.tensorboard.RewriterConfigJ\x04\x08\x01\x10\x02R%skip_common_subexpression_elimination\"A\n\x15ThreadPoolOptionProto\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0bglobal_name\x18\x02 \x01(\t\"0\n\x0fSessionMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x03\"\x9f\x10\n\x0b\x43onfigProto\x12?\n\x0c\x64\x65vice_count\x18\x01 \x03(\x0b\x32).tensorboard.ConfigProto.DeviceCountEntry\x12$\n\x1cintra_op_parallelism_threads\x18\x02 \x01(\x05\x12$\n\x1cinter_op_parallelism_threads\x18\x05 \x01(\x05\x12\x1f\n\x17use_per_session_threads\x18\t \x01(\x08\x12H\n\x1csession_inter_op_thread_pool\x18\x0c \x03(\x0b\x32\".tensorboard.ThreadPoolOptionProto\x12\x18\n\x10placement_period\x18\x03 \x01(\x05\x12\x16\n\x0e\x64\x65vice_filters\x18\x04 \x03(\t\x12,\n\x0bgpu_options\x18\x06 \x01(\x0b\x32\x17.tensorboard.GPUOptions\x12\x1c\n\x14\x61llow_soft_placement\x18\x07 \x01(\x08\x12\x1c\n\x14log_device_placement\x18\x08 \x01(\x08\x12\x30\n\rgraph_options\x18\n \x01(\x0b\x32\x19.tensorboard.GraphOptions\x12\x1f\n\x17operation_timeout_in_ms\x18\x0b \x01(\x03\x12,\n\x0brpc_options\x18\r \x01(\x0b\x32\x17.tensorboard.RPCOptions\x12,\n\x0b\x63luster_def\x18\x0e \x01(\x0b\x32\x17.tensorboard.ClusterDef\x12\x1d\n\x15isolate_session_state\x18\x0f \x01(\x08\x12(\n share_cluster_devices_in_session\x18\x11 \x01(\x08\x12;\n\x0c\x65xperimental\x18\x10 \x01(\x0b\x32%.tensorboard.ConfigProto.Experimental\x1a\x32\n\x10\x44\x65viceCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x92\n\n\x0c\x45xperimental\x12\x1f\n\x17\x63ollective_group_leader\x18\x01 \x01(\t\x12\x15\n\rexecutor_type\x18\x03 \x01(\t\x12\x1a\n\x12recv_buf_max_chunk\x18\x04 \x01(\x05\x12\x19\n\x11use_numa_affinity\x18\x05 \x01(\x08\x12\x35\n-collective_deterministic_sequential_execution\x18\x06 \x01(\x08\x12\x17\n\x0f\x63ollective_nccl\x18\x07 \x01(\x08\x12\x36\n.share_session_state_in_clusterspec_propagation\x18\x08 \x01(\x08\x12\x1f\n\x17\x64isable_thread_spinning\x18\t \x01(\x08\x12(\n share_cluster_devices_in_session\x18\n \x01(\x08\x12\x36\n\x10session_metadata\x18\x0b \x01(\x0b\x32\x1c.tensorboard.SessionMetadata\x12!\n\x19optimize_for_static_graph\x18\x0c \x01(\x08\x12\x1a\n\x12\x65nable_mlir_bridge\x18\r \x01(\x08\x12T\n\x13mlir_bridge_rollout\x18\x11 \x01(\x0e\x32\x37.tensorboard.ConfigProto.Experimental.MlirBridgeRollout\x12&\n\x1e\x65nable_mlir_graph_optimization\x18\x10 \x01(\x08\x12\'\n\x1f\x64isable_output_partition_graphs\x18\x0e \x01(\x08\x12#\n\x1bxla_fusion_autotuner_thresh\x18\x0f \x01(\x03\x12\x10\n\x08use_tfrt\x18\x12 \x01(\x08\x12\x19\n\x11\x65nable_multi_host\x18\x1b \x01(\x08\x12\x1b\n\x13\x62\x61\x63kend_server_port\x18\x1c \x01(\x05\x12\x12\n\ntarget_tpu\x18\x1d \x01(\x08\x12\x12\n\ntarget_gpu\x18\x1e \x01(\x08\x12\x1e\n\x16stream_merge_threshold\x18\x1f \x01(\x05\x12\'\n\x1f\x64isable_functional_ops_lowering\x18\x15 \x01(\x08\x12\'\n\x1fxla_prefer_single_graph_cluster\x18\x16 \x01(\x08\x12\x43\n\x13\x63oordination_config\x18\x17 \x01(\x0b\x32&.tensorboard.CoordinationServiceConfig\x12)\n!disable_optimize_for_static_graph\x18\x18 \x01(\x08\x12\x30\n(disable_eager_executor_streaming_enqueue\x18\x1a \x01(\x08\"\xde\x01\n\x11MlirBridgeRollout\x12#\n\x1fMLIR_BRIDGE_ROLLOUT_UNSPECIFIED\x10\x00\x12\x1f\n\x1bMLIR_BRIDGE_ROLLOUT_ENABLED\x10\x01\x12 \n\x1cMLIR_BRIDGE_ROLLOUT_DISABLED\x10\x02\"\x04\x08\x03\x10\x03\"\x04\x08\x04\x10\x04*%MLIR_BRIDGE_ROLLOUT_SAFE_MODE_ENABLED*.MLIR_BRIDGE_ROLLOUT_SAFE_MODE_FALLBACK_ENABLEDJ\x04\x08\x02\x10\x03J\x04\x08\x13\x10\x14J\x04\x08\x14\x10\x15J\x04\x08\x19\x10\x1a\"\xe5\x04\n\nRunOptions\x12\x37\n\x0btrace_level\x18\x01 \x01(\x0e\x32\".tensorboard.RunOptions.TraceLevel\x12\x15\n\rtimeout_in_ms\x18\x02 \x01(\x03\x12\x1c\n\x14inter_op_thread_pool\x18\x03 \x01(\x05\x12\x1f\n\x17output_partition_graphs\x18\x05 \x01(\x08\x12\x30\n\rdebug_options\x18\x06 \x01(\x0b\x32\x19.tensorboard.DebugOptions\x12*\n\"report_tensor_allocations_upon_oom\x18\x07 \x01(\x08\x12:\n\x0c\x65xperimental\x18\x08 \x01(\x0b\x32$.tensorboard.RunOptions.Experimental\x1a\xd3\x01\n\x0c\x45xperimental\x12\x1c\n\x14\x63ollective_graph_key\x18\x01 \x01(\x03\x12\x1c\n\x14use_run_handler_pool\x18\x02 \x01(\x08\x12\\\n\x18run_handler_pool_options\x18\x03 \x01(\x0b\x32:.tensorboard.RunOptions.Experimental.RunHandlerPoolOptions\x1a)\n\x15RunHandlerPoolOptions\x12\x10\n\x08priority\x18\x01 \x01(\x03\"R\n\nTraceLevel\x12\x0c\n\x08NO_TRACE\x10\x00\x12\x12\n\x0eSOFTWARE_TRACE\x10\x01\x12\x12\n\x0eHARDWARE_TRACE\x10\x02\x12\x0e\n\nFULL_TRACE\x10\x03J\x04\x08\x04\x10\x05\"\xc6\x03\n\x0bRunMetadata\x12*\n\nstep_stats\x18\x01 \x01(\x0b\x32\x16.tensorboard.StepStats\x12-\n\ncost_graph\x18\x02 \x01(\x0b\x32\x19.tensorboard.CostGraphDef\x12/\n\x10partition_graphs\x18\x03 \x03(\x0b\x32\x15.tensorboard.GraphDef\x12@\n\x0f\x66unction_graphs\x18\x04 \x03(\x0b\x32\'.tensorboard.RunMetadata.FunctionGraphs\x12\x36\n\x10session_metadata\x18\x05 \x01(\x0b\x32\x1c.tensorboard.SessionMetadata\x1a\xb0\x01\n\x0e\x46unctionGraphs\x12/\n\x10partition_graphs\x18\x01 \x03(\x0b\x32\x15.tensorboard.GraphDef\x12\x35\n\x16pre_optimization_graph\x18\x02 \x01(\x0b\x32\x15.tensorboard.GraphDef\x12\x36\n\x17post_optimization_graph\x18\x03 \x01(\x0b\x32\x15.tensorboard.GraphDef\":\n\x10TensorConnection\x12\x13\n\x0b\x66rom_tensor\x18\x01 \x01(\t\x12\x11\n\tto_tensor\x18\x02 \x01(\t\"\xb4\x03\n\x0f\x43\x61llableOptions\x12\x0c\n\x04\x66\x65\x65\x64\x18\x01 \x03(\t\x12\r\n\x05\x66\x65tch\x18\x02 \x03(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12,\n\x0brun_options\x18\x04 \x01(\x0b\x32\x17.tensorboard.RunOptions\x12\x38\n\x11tensor_connection\x18\x05 \x03(\x0b\x32\x1d.tensorboard.TensorConnection\x12\x43\n\x0c\x66\x65\x65\x64_devices\x18\x06 \x03(\x0b\x32-.tensorboard.CallableOptions.FeedDevicesEntry\x12\x45\n\rfetch_devices\x18\x07 \x03(\x0b\x32..tensorboard.CallableOptions.FetchDevicesEntry\x12\x17\n\x0f\x66\x65tch_skip_sync\x18\x08 \x01(\x08\x1a\x32\n\x10\x46\x65\x65\x64\x44\x65vicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x46\x65tchDevicesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x84\x01\n\x18org.tensorflow.frameworkB\x0c\x43onfigProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01\x62\x06proto3')



_GPUOPTIONS = DESCRIPTOR.message_types_by_name['GPUOptions']
_GPUOPTIONS_EXPERIMENTAL = _GPUOPTIONS.nested_types_by_name['Experimental']
_GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES = _GPUOPTIONS_EXPERIMENTAL.nested_types_by_name['VirtualDevices']
_GPUOPTIONS_EXPERIMENTAL_STREAMMERGEOPTIONS = _GPUOPTIONS_EXPERIMENTAL.nested_types_by_name['StreamMergeOptions']
_OPTIMIZEROPTIONS = DESCRIPTOR.message_types_by_name['OptimizerOptions']
_GRAPHOPTIONS = DESCRIPTOR.message_types_by_name['GraphOptions']
_THREADPOOLOPTIONPROTO = DESCRIPTOR.message_types_by_name['ThreadPoolOptionProto']
_SESSIONMETADATA = DESCRIPTOR.message_types_by_name['SessionMetadata']
_CONFIGPROTO = DESCRIPTOR.message_types_by_name['ConfigProto']
_CONFIGPROTO_DEVICECOUNTENTRY = _CONFIGPROTO.nested_types_by_name['DeviceCountEntry']
_CONFIGPROTO_EXPERIMENTAL = _CONFIGPROTO.nested_types_by_name['Experimental']
_RUNOPTIONS = DESCRIPTOR.message_types_by_name['RunOptions']
_RUNOPTIONS_EXPERIMENTAL = _RUNOPTIONS.nested_types_by_name['Experimental']
_RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS = _RUNOPTIONS_EXPERIMENTAL.nested_types_by_name['RunHandlerPoolOptions']
_RUNMETADATA = DESCRIPTOR.message_types_by_name['RunMetadata']
_RUNMETADATA_FUNCTIONGRAPHS = _RUNMETADATA.nested_types_by_name['FunctionGraphs']
_TENSORCONNECTION = DESCRIPTOR.message_types_by_name['TensorConnection']
_CALLABLEOPTIONS = DESCRIPTOR.message_types_by_name['CallableOptions']
_CALLABLEOPTIONS_FEEDDEVICESENTRY = _CALLABLEOPTIONS.nested_types_by_name['FeedDevicesEntry']
_CALLABLEOPTIONS_FETCHDEVICESENTRY = _CALLABLEOPTIONS.nested_types_by_name['FetchDevicesEntry']
_OPTIMIZEROPTIONS_LEVEL = _OPTIMIZEROPTIONS.enum_types_by_name['Level']
_OPTIMIZEROPTIONS_GLOBALJITLEVEL = _OPTIMIZEROPTIONS.enum_types_by_name['GlobalJitLevel']
_CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT = _CONFIGPROTO_EXPERIMENTAL.enum_types_by_name['MlirBridgeRollout']
_RUNOPTIONS_TRACELEVEL = _RUNOPTIONS.enum_types_by_name['TraceLevel']
GPUOptions = _reflection.GeneratedProtocolMessageType('GPUOptions', (_message.Message,), {

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {

    'VirtualDevices' : _reflection.GeneratedProtocolMessageType('VirtualDevices', (_message.Message,), {
      'DESCRIPTOR' : _GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES,
      '__module__' : 'tensorboard.compat.proto.config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions.Experimental.VirtualDevices)
      })
    ,

    'StreamMergeOptions' : _reflection.GeneratedProtocolMessageType('StreamMergeOptions', (_message.Message,), {
      'DESCRIPTOR' : _GPUOPTIONS_EXPERIMENTAL_STREAMMERGEOPTIONS,
      '__module__' : 'tensorboard.compat.proto.config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions.Experimental.StreamMergeOptions)
      })
    ,
    'DESCRIPTOR' : _GPUOPTIONS_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions.Experimental)
    })
  ,
  'DESCRIPTOR' : _GPUOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.GPUOptions)
  })
_sym_db.RegisterMessage(GPUOptions)
_sym_db.RegisterMessage(GPUOptions.Experimental)
_sym_db.RegisterMessage(GPUOptions.Experimental.VirtualDevices)
_sym_db.RegisterMessage(GPUOptions.Experimental.StreamMergeOptions)

OptimizerOptions = _reflection.GeneratedProtocolMessageType('OptimizerOptions', (_message.Message,), {
  'DESCRIPTOR' : _OPTIMIZEROPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.OptimizerOptions)
  })
_sym_db.RegisterMessage(OptimizerOptions)

GraphOptions = _reflection.GeneratedProtocolMessageType('GraphOptions', (_message.Message,), {
  'DESCRIPTOR' : _GRAPHOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.GraphOptions)
  })
_sym_db.RegisterMessage(GraphOptions)

ThreadPoolOptionProto = _reflection.GeneratedProtocolMessageType('ThreadPoolOptionProto', (_message.Message,), {
  'DESCRIPTOR' : _THREADPOOLOPTIONPROTO,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ThreadPoolOptionProto)
  })
_sym_db.RegisterMessage(ThreadPoolOptionProto)

SessionMetadata = _reflection.GeneratedProtocolMessageType('SessionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONMETADATA,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.SessionMetadata)
  })
_sym_db.RegisterMessage(SessionMetadata)

ConfigProto = _reflection.GeneratedProtocolMessageType('ConfigProto', (_message.Message,), {

  'DeviceCountEntry' : _reflection.GeneratedProtocolMessageType('DeviceCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGPROTO_DEVICECOUNTENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto.DeviceCountEntry)
    })
  ,

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGPROTO_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto.Experimental)
    })
  ,
  'DESCRIPTOR' : _CONFIGPROTO,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ConfigProto)
  })
_sym_db.RegisterMessage(ConfigProto)
_sym_db.RegisterMessage(ConfigProto.DeviceCountEntry)
_sym_db.RegisterMessage(ConfigProto.Experimental)

RunOptions = _reflection.GeneratedProtocolMessageType('RunOptions', (_message.Message,), {

  'Experimental' : _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {

    'RunHandlerPoolOptions' : _reflection.GeneratedProtocolMessageType('RunHandlerPoolOptions', (_message.Message,), {
      'DESCRIPTOR' : _RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS,
      '__module__' : 'tensorboard.compat.proto.config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.RunOptions.Experimental.RunHandlerPoolOptions)
      })
    ,
    'DESCRIPTOR' : _RUNOPTIONS_EXPERIMENTAL,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.RunOptions.Experimental)
    })
  ,
  'DESCRIPTOR' : _RUNOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RunOptions)
  })
_sym_db.RegisterMessage(RunOptions)
_sym_db.RegisterMessage(RunOptions.Experimental)
_sym_db.RegisterMessage(RunOptions.Experimental.RunHandlerPoolOptions)

RunMetadata = _reflection.GeneratedProtocolMessageType('RunMetadata', (_message.Message,), {

  'FunctionGraphs' : _reflection.GeneratedProtocolMessageType('FunctionGraphs', (_message.Message,), {
    'DESCRIPTOR' : _RUNMETADATA_FUNCTIONGRAPHS,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.RunMetadata.FunctionGraphs)
    })
  ,
  'DESCRIPTOR' : _RUNMETADATA,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RunMetadata)
  })
_sym_db.RegisterMessage(RunMetadata)
_sym_db.RegisterMessage(RunMetadata.FunctionGraphs)

TensorConnection = _reflection.GeneratedProtocolMessageType('TensorConnection', (_message.Message,), {
  'DESCRIPTOR' : _TENSORCONNECTION,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.TensorConnection)
  })
_sym_db.RegisterMessage(TensorConnection)

CallableOptions = _reflection.GeneratedProtocolMessageType('CallableOptions', (_message.Message,), {

  'FeedDevicesEntry' : _reflection.GeneratedProtocolMessageType('FeedDevicesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CALLABLEOPTIONS_FEEDDEVICESENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions.FeedDevicesEntry)
    })
  ,

  'FetchDevicesEntry' : _reflection.GeneratedProtocolMessageType('FetchDevicesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CALLABLEOPTIONS_FETCHDEVICESENTRY,
    '__module__' : 'tensorboard.compat.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions.FetchDevicesEntry)
    })
  ,
  'DESCRIPTOR' : _CALLABLEOPTIONS,
  '__module__' : 'tensorboard.compat.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.CallableOptions)
  })
_sym_db.RegisterMessage(CallableOptions)
_sym_db.RegisterMessage(CallableOptions.FeedDevicesEntry)
_sym_db.RegisterMessage(CallableOptions.FetchDevicesEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\014ConfigProtosP\001ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\370\001\001'
  _CONFIGPROTO_DEVICECOUNTENTRY._options = None
  _CONFIGPROTO_DEVICECOUNTENTRY._serialized_options = b'8\001'
  _CALLABLEOPTIONS_FEEDDEVICESENTRY._options = None
  _CALLABLEOPTIONS_FEEDDEVICESENTRY._serialized_options = b'8\001'
  _CALLABLEOPTIONS_FETCHDEVICESENTRY._options = None
  _CALLABLEOPTIONS_FETCHDEVICESENTRY._serialized_options = b'8\001'
  _GPUOPTIONS._serialized_start=401
  _GPUOPTIONS._serialized_end=1693
  _GPUOPTIONS_EXPERIMENTAL._serialized_start=729
  _GPUOPTIONS_EXPERIMENTAL._serialized_end=1693
  _GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES._serialized_start=1474
  _GPUOPTIONS_EXPERIMENTAL_VIRTUALDEVICES._serialized_end=1557
  _GPUOPTIONS_EXPERIMENTAL_STREAMMERGEOPTIONS._serialized_start=1560
  _GPUOPTIONS_EXPERIMENTAL_STREAMMERGEOPTIONS._serialized_end=1693
  _OPTIMIZEROPTIONS._serialized_start=1696
  _OPTIMIZEROPTIONS._serialized_end=2111
  _OPTIMIZEROPTIONS_LEVEL._serialized_start=2010
  _OPTIMIZEROPTIONS_LEVEL._serialized_end=2042
  _OPTIMIZEROPTIONS_GLOBALJITLEVEL._serialized_start=2044
  _OPTIMIZEROPTIONS_GLOBALJITLEVEL._serialized_end=2111
  _GRAPHOPTIONS._serialized_start=2114
  _GRAPHOPTIONS._serialized_end=2482
  _THREADPOOLOPTIONPROTO._serialized_start=2484
  _THREADPOOLOPTIONPROTO._serialized_end=2549
  _SESSIONMETADATA._serialized_start=2551
  _SESSIONMETADATA._serialized_end=2599
  _CONFIGPROTO._serialized_start=2602
  _CONFIGPROTO._serialized_end=4681
  _CONFIGPROTO_DEVICECOUNTENTRY._serialized_start=3330
  _CONFIGPROTO_DEVICECOUNTENTRY._serialized_end=3380
  _CONFIGPROTO_EXPERIMENTAL._serialized_start=3383
  _CONFIGPROTO_EXPERIMENTAL._serialized_end=4681
  _CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT._serialized_start=4435
  _CONFIGPROTO_EXPERIMENTAL_MLIRBRIDGEROLLOUT._serialized_end=4657
  _RUNOPTIONS._serialized_start=4684
  _RUNOPTIONS._serialized_end=5297
  _RUNOPTIONS_EXPERIMENTAL._serialized_start=4996
  _RUNOPTIONS_EXPERIMENTAL._serialized_end=5207
  _RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS._serialized_start=5166
  _RUNOPTIONS_EXPERIMENTAL_RUNHANDLERPOOLOPTIONS._serialized_end=5207
  _RUNOPTIONS_TRACELEVEL._serialized_start=5209
  _RUNOPTIONS_TRACELEVEL._serialized_end=5291
  _RUNMETADATA._serialized_start=5300
  _RUNMETADATA._serialized_end=5754
  _RUNMETADATA_FUNCTIONGRAPHS._serialized_start=5578
  _RUNMETADATA_FUNCTIONGRAPHS._serialized_end=5754
  _TENSORCONNECTION._serialized_start=5756
  _TENSORCONNECTION._serialized_end=5814
  _CALLABLEOPTIONS._serialized_start=5817
  _CALLABLEOPTIONS._serialized_end=6253
  _CALLABLEOPTIONS_FEEDDEVICESENTRY._serialized_start=6150
  _CALLABLEOPTIONS_FEEDDEVICESENTRY._serialized_end=6200
  _CALLABLEOPTIONS_FETCHDEVICESENTRY._serialized_start=6202
  _CALLABLEOPTIONS_FETCHDEVICESENTRY._serialized_end=6253
# @@protoc_insertion_point(module_scope)



# Copyright 2023 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

import math


def is_serializable_value(value):
    """Returns whether a protobuf Value will be serializable by MessageToJson.

    The json_format documentation states that "attempting to serialize NaN or
    Infinity results in error."

    https://protobuf.dev/reference/protobuf/google.protobuf/#value

    Args:
      value: A value of type protobuf.Value.

    Returns:
      True if the Value should be serializable without error by MessageToJson.
      False, otherwise.
    """
    if not value.HasField("number_value"):
        return True

    number_value = value.number_value
    return not math.isnan(number_value) and not math.isinf(number_value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/rewriter_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import attr_value_pb2 as tensorboard_dot_compat_dot_proto_dot_attr__value__pb2
from tensorboard.compat.proto import verifier_config_pb2 as tensorboard_dot_compat_dot_proto_dot_verifier__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.tensorboard/compat/proto/rewriter_config.proto\x12\x0btensorboard\x1a)tensorboard/compat/proto/attr_value.proto\x1a.tensorboard/compat/proto/verifier_config.proto\";\n\x13\x41utoParallelOptions\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x14\n\x0cnum_replicas\x18\x02 \x01(\x05\"+\n\x16ScopedAllocatorOptions\x12\x11\n\tenable_op\x18\x01 \x03(\t\"\xb2\x16\n\x0eRewriterConfig\x12\x44\n\x15\x63pu_layout_conversion\x18\x32 \x01(\x0e\x32%.tensorboard.RewriterConfig.CpuLayout\x12<\n\x10layout_optimizer\x18\x01 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12<\n\x10\x63onstant_folding\x18\x03 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12>\n\x12shape_optimization\x18\r \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x35\n\tremapping\x18\x0e \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12G\n\x1b\x63ommon_subgraph_elimination\x18\x18 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x43\n\x17\x61rithmetic_optimization\x18\x07 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x43\n\x17\x64\x65pendency_optimization\x18\x08 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12=\n\x11loop_optimization\x18\t \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x41\n\x15\x66unction_optimization\x18\n \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12:\n\x0e\x64\x65\x62ug_stripper\x18\x0b \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x1d\n\x15\x64isable_model_pruning\x18\x02 \x01(\x08\x12I\n\x1dscoped_allocator_optimization\x18\x0f \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x44\n\x18pin_to_host_optimization\x18\x12 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x43\n\x17implementation_selector\x18\x16 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12@\n\x14\x61uto_mixed_precision\x18\x17 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x44\n\x18\x61uto_mixed_precision_mkl\x18\x19 \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12P\n$auto_mixed_precision_onednn_bfloat16\x18\x1f \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x44\n\x18\x61uto_mixed_precision_cpu\x18\x1d \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12\x1e\n\x16\x64isable_meta_optimizer\x18\x13 \x01(\x08\x12\x1d\n\x15\x64isable_tfg_optimizer\x18  \x01(\x08\x12\x41\n\x15use_plugin_optimizers\x18\x1c \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12P\n$experimental_conditional_code_motion\x18\x1e \x01(\x0e\x32\".tensorboard.RewriterConfig.Toggle\x12P\n\x19meta_optimizer_iterations\x18\x0c \x01(\x0e\x32-.tensorboard.RewriterConfig.NumIterationsType\x12\x17\n\x0fmin_graph_nodes\x18\x11 \x01(\x05\x12;\n3experimental_disable_compressed_tensor_optimization\x18\x1a \x01(\x08\x12;\n3experimental_disable_folding_quantization_emulation\x18\x1b \x01(\x08\x12\x43\n\x13memory_optimization\x18\x04 \x01(\x0e\x32&.tensorboard.RewriterConfig.MemOptType\x12/\n\'memory_optimizer_target_node_name_scope\x18\x06 \x01(\t\x12!\n\x19meta_optimizer_timeout_ms\x18\x14 \x01(\x03\x12\x37\n\rauto_parallel\x18\x05 \x01(\x0b\x32 .tensorboard.AutoParallelOptions\x12 \n\x18\x66\x61il_on_optimizer_errors\x18\x15 \x01(\x08\x12\x42\n\x15scoped_allocator_opts\x18\x10 \x01(\x0b\x32#.tensorboard.ScopedAllocatorOptions\x12\x12\n\noptimizers\x18\x64 \x03(\t\x12L\n\x11\x63ustom_optimizers\x18\xc8\x01 \x03(\x0b\x32\x30.tensorboard.RewriterConfig.CustomGraphOptimizer\x12\x45\n\x1finter_optimizer_verifier_config\x18\xac\x02 \x01(\x0b\x32\x1b.tensorboard.VerifierConfig\x12G\n!post_optimization_verifier_config\x18\xad\x02 \x01(\x0b\x32\x1b.tensorboard.VerifierConfig\x1a\xcc\x01\n\x14\x43ustomGraphOptimizer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Y\n\rparameter_map\x18\x02 \x03(\x0b\x32\x42.tensorboard.RewriterConfig.CustomGraphOptimizer.ParameterMapEntry\x1aK\n\x11ParameterMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.tensorboard.AttrValue:\x02\x38\x01\"d\n\x06Toggle\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02\x12\x0e\n\nAGGRESSIVE\x10\x03\x12\x15\n\x11\x45XPERIMENTAL_MLIR\x10\x04\x12\x15\n\x11\x45XPERIMENTAL_BOTH\x10\x05\"I\n\tCpuLayout\x12\x18\n\x14NO_CONVERSION_ON_CPU\x10\x00\x12\x10\n\x0cNCHW_TO_NHWC\x10\x01\x12\x10\n\x0cNHWC_TO_NCHW\x10\x02\"<\n\x11NumIterationsType\x12\x15\n\x11\x44\x45\x46\x41ULT_NUM_ITERS\x10\x00\x12\x07\n\x03ONE\x10\x01\x12\x07\n\x03TWO\x10\x02\"\x9f\x01\n\nMemOptType\x12\x13\n\x0f\x44\x45\x46\x41ULT_MEM_OPT\x10\x00\x12\x0e\n\nNO_MEM_OPT\x10\x01\x12\n\n\x06MANUAL\x10\x02\x12\x17\n\x13SWAPPING_HEURISTICS\x10\x04\x12\x1c\n\x18RECOMPUTATION_HEURISTICS\x10\x05\x12\x19\n\x15SCHEDULING_HEURISTICS\x10\x06\x12\x0e\n\nHEURISTICS\x10\x03\x42\x8c\x01\n\x18org.tensorflow.frameworkB\x14RewriterConfigProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01\x62\x06proto3')



_AUTOPARALLELOPTIONS = DESCRIPTOR.message_types_by_name['AutoParallelOptions']
_SCOPEDALLOCATOROPTIONS = DESCRIPTOR.message_types_by_name['ScopedAllocatorOptions']
_REWRITERCONFIG = DESCRIPTOR.message_types_by_name['RewriterConfig']
_REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER = _REWRITERCONFIG.nested_types_by_name['CustomGraphOptimizer']
_REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY = _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER.nested_types_by_name['ParameterMapEntry']
_REWRITERCONFIG_TOGGLE = _REWRITERCONFIG.enum_types_by_name['Toggle']
_REWRITERCONFIG_CPULAYOUT = _REWRITERCONFIG.enum_types_by_name['CpuLayout']
_REWRITERCONFIG_NUMITERATIONSTYPE = _REWRITERCONFIG.enum_types_by_name['NumIterationsType']
_REWRITERCONFIG_MEMOPTTYPE = _REWRITERCONFIG.enum_types_by_name['MemOptType']
AutoParallelOptions = _reflection.GeneratedProtocolMessageType('AutoParallelOptions', (_message.Message,), {
  'DESCRIPTOR' : _AUTOPARALLELOPTIONS,
  '__module__' : 'tensorboard.compat.proto.rewriter_config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.AutoParallelOptions)
  })
_sym_db.RegisterMessage(AutoParallelOptions)

ScopedAllocatorOptions = _reflection.GeneratedProtocolMessageType('ScopedAllocatorOptions', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDALLOCATOROPTIONS,
  '__module__' : 'tensorboard.compat.proto.rewriter_config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ScopedAllocatorOptions)
  })
_sym_db.RegisterMessage(ScopedAllocatorOptions)

RewriterConfig = _reflection.GeneratedProtocolMessageType('RewriterConfig', (_message.Message,), {

  'CustomGraphOptimizer' : _reflection.GeneratedProtocolMessageType('CustomGraphOptimizer', (_message.Message,), {

    'ParameterMapEntry' : _reflection.GeneratedProtocolMessageType('ParameterMapEntry', (_message.Message,), {
      'DESCRIPTOR' : _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY,
      '__module__' : 'tensorboard.compat.proto.rewriter_config_pb2'
      # @@protoc_insertion_point(class_scope:tensorboard.RewriterConfig.CustomGraphOptimizer.ParameterMapEntry)
      })
    ,
    'DESCRIPTOR' : _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER,
    '__module__' : 'tensorboard.compat.proto.rewriter_config_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.RewriterConfig.CustomGraphOptimizer)
    })
  ,
  'DESCRIPTOR' : _REWRITERCONFIG,
  '__module__' : 'tensorboard.compat.proto.rewriter_config_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.RewriterConfig)
  })
_sym_db.RegisterMessage(RewriterConfig)
_sym_db.RegisterMessage(RewriterConfig.CustomGraphOptimizer)
_sym_db.RegisterMessage(RewriterConfig.CustomGraphOptimizer.ParameterMapEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\024RewriterConfigProtosP\001ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\370\001\001'
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY._options = None
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY._serialized_options = b'8\001'
  _AUTOPARALLELOPTIONS._serialized_start=154
  _AUTOPARALLELOPTIONS._serialized_end=213
  _SCOPEDALLOCATOROPTIONS._serialized_start=215
  _SCOPEDALLOCATOROPTIONS._serialized_end=258
  _REWRITERCONFIG._serialized_start=261
  _REWRITERCONFIG._serialized_end=3127
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER._serialized_start=2522
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER._serialized_end=2726
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY._serialized_start=2651
  _REWRITERCONFIG_CUSTOMGRAPHOPTIMIZER_PARAMETERMAPENTRY._serialized_end=2726
  _REWRITERCONFIG_TOGGLE._serialized_start=2728
  _REWRITERCONFIG_TOGGLE._serialized_end=2828
  _REWRITERCONFIG_CPULAYOUT._serialized_start=2830
  _REWRITERCONFIG_CPULAYOUT._serialized_end=2903
  _REWRITERCONFIG_NUMITERATIONSTYPE._serialized_start=2905
  _REWRITERCONFIG_NUMITERATIONSTYPE._serialized_end=2965
  _REWRITERCONFIG_MEMOPTTYPE._serialized_start=2968
  _REWRITERCONFIG_MEMOPTTYPE._serialized_end=3127
# @@protoc_insertion_point(module_scope)



# Copyright 2015 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

"""Contains the implementation for the DirectoryWatcher class."""

import bisect

from tensorboard.backend.event_processing import io_wrapper
from tensorboard.compat import tf
from tensorboard.util import io_util
from tensorboard.util import tb_logging


logger = tb_logging.get_logger()


class DirectoryWatcher:
    """A DirectoryWatcher wraps a loader to load from a sequence of paths.

    A loader reads a path and produces some kind of values as an iterator. A
    DirectoryWatcher takes a directory, a factory for loaders, and optionally a
    path filter and watches all the paths inside that directory.

    This class is only valid under the assumption that only one path will be
    written to by the data source at a time and that once the source stops writing
    to a path, it will start writing to a new path that's lexicographically
    greater and never come back. It uses some heuristics to check whether this is
    true based on tracking changes to the files' sizes, but the check can have
    false negatives. However, it should have no false positives.
    """

    def __init__(self, directory, loader_factory, path_filter=lambda x: True):
        """Constructs a new DirectoryWatcher.

        Args:
          directory: The directory to load files from.
          loader_factory: A factory for creating loaders. The factory should take a
            path and return an object that has a Load method returning an
            iterator that will yield all events that have not been yielded yet.
          path_filter: If specified, only paths matching this filter are loaded.

        Raises:
          ValueError: If path_provider or loader_factory are None.
        """
        if directory is None:
            raise ValueError("A directory is required")
        if loader_factory is None:
            raise ValueError("A loader factory is required")
        self._directory = directory
        self._path = None
        self._loader_factory = loader_factory
        self._loader = None
        self._path_filter = path_filter
        self._ooo_writes_detected = False
        # The file size for each file at the time it was finalized.
        self._finalized_sizes = {}

    def Load(self):
        """Loads new values.

        The watcher will load from one path at a time; as soon as that path stops
        yielding events, it will move on to the next path. We assume that old paths
        are never modified after a newer path has been written. As a result, Load()
        can be called multiple times in a row without losing events that have not
        been yielded yet. In other words, we guarantee that every event will be
        yielded exactly once.

        Yields:
          All values that have not been yielded yet.

        Raises:
          DirectoryDeletedError: If the directory has been permanently deleted
            (as opposed to being temporarily unavailable).
        """
        try:
            for event in self._LoadInternal():
                yield event
        except tf.errors.OpError:
            if not tf.io.gfile.exists(self._directory):
                raise DirectoryDeletedError(
                    "Directory %s has been permanently deleted"
                    % self._directory
                )

    def _LoadInternal(self):
        """Internal implementation of Load().

        The only difference between this and Load() is that the latter will throw
        DirectoryDeletedError on I/O errors if it thinks that the directory has been
        permanently deleted.

        Yields:
          All values that have not been yielded yet.
        """

        # If the loader exists, check it for a value.
        if not self._loader:
            self._InitializeLoader()

        # If it still doesn't exist, there is no data
        if not self._loader:
            return

        while True:
            # Yield all the new events in the path we're currently loading from.
            for event in self._loader.Load():
                yield event

            next_path = self._GetNextPath()
            if not next_path:
                logger.info("No path found after %s", self._path)
                # Current path is empty and there are no new paths, so we're done.
                return

            # There's a new path, so check to make sure there weren't any events
            # written between when we finished reading the current path and when we
            # checked for the new one. The sequence of events might look something
            # like this:
            #
            # 1. Event #1 written to path #1.
            # 2. We check for events and yield event #1 from path #1
            # 3. We check for events and see that there are no more events in path #1.
            # 4. Event #2 is written to path #1.
            # 5. Event #3 is written to path #2.
            # 6. We check for a new path and see that path #2 exists.
            #
            # Without this loop, we would miss event #2. We're also guaranteed by the
            # loader contract that no more events will be written to path #1 after
            # events start being written to path #2, so we don't have to worry about
            # that.
            for event in self._loader.Load():
                yield event

            logger.info(
                "Directory watcher advancing from %s to %s",
                self._path,
                next_path,
            )

            # Advance to the next path and start over.
            self._SetPath(next_path)

    # The number of paths before the current one to check for out of order writes.
    _OOO_WRITE_CHECK_COUNT = 20

    def OutOfOrderWritesDetected(self):
        """Returns whether any out-of-order writes have been detected.

        Out-of-order writes are only checked as part of the Load() iterator. Once an
        out-of-order write is detected, this function will always return true.

        Note that out-of-order write detection is not performed on GCS paths, so
        this function will always return false.

        Returns:
          Whether any out-of-order write has ever been detected by this watcher.
        """
        return self._ooo_writes_detected

    def _InitializeLoader(self):
        path = self._GetNextPath()
        if path:
            self._SetPath(path)

    def _SetPath(self, path):
        """Sets the current path to watch for new events.

        This also records the size of the old path, if any. If the size can't be
        found, an error is logged.

        Args:
          path: The full path of the file to watch.
        """
        old_path = self._path
        if old_path and not io_util.IsCloudPath(old_path):
            try:
                # We're done with the path, so store its size.
                size = tf.io.gfile.stat(old_path).length
                logger.debug("Setting latest size of %s to %d", old_path, size)
                self._finalized_sizes[old_path] = size
            except tf.errors.OpError as e:
                logger.error("Unable to get size of %s: %s", old_path, e)

        self._path = path
        self._loader = self._loader_factory(path)

    def _GetNextPath(self):
        """Gets the next path to load from.

        This function also does the checking for out-of-order writes as it iterates
        through the paths.

        Returns:
          The next path to load events from, or None if there are no more paths.
        """
        paths = sorted(
            path
            for path in io_wrapper.ListDirectoryAbsolute(self._directory)
            if self._path_filter(path)
        )
        if not paths:
            return None

        if self._path is None:
            return paths[0]

        # Don't bother checking if the paths are GCS (which we can't check) or if
        # we've already detected an OOO write.
        if not io_util.IsCloudPath(paths[0]) and not self._ooo_writes_detected:
            # Check the previous _OOO_WRITE_CHECK_COUNT paths for out of order writes.
            current_path_index = bisect.bisect_left(paths, self._path)
            ooo_check_start = max(
                0, current_path_index - self._OOO_WRITE_CHECK_COUNT
            )
            for path in paths[ooo_check_start:current_path_index]:
                if self._HasOOOWrite(path):
                    self._ooo_writes_detected = True
                    break

        next_paths = list(
            path for path in paths if self._path is None or path > self._path
        )
        if next_paths:
            return min(next_paths)
        else:
            return None

    def _HasOOOWrite(self, path):
        """Returns whether the path has had an out-of-order write."""
        # Check the sizes of each path before the current one.
        size = tf.io.gfile.stat(path).length
        old_size = self._finalized_sizes.get(path, None)
        if size != old_size:
            if old_size is None:
                logger.error(
                    "File %s created after file %s even though it's "
                    "lexicographically earlier",
                    path,
                    self._path,
                )
            else:
                logger.error(
                    "File %s updated even though the current file is %s",
                    path,
                    self._path,
                )
            return True
        else:
            return False


class DirectoryDeletedError(Exception):
    """Thrown by Load() when the directory is *permanently* gone.

    We distinguish this from temporary errors so that other code can
    decide to drop all of our data only when a directory has been
    intentionally deleted, as opposed to due to transient filesystem
    errors.
    """

    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/full_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(tensorboard/compat/proto/full_type.proto\x12\x0btensorboard\"\x81\x01\n\x0b\x46ullTypeDef\x12(\n\x07type_id\x18\x01 \x01(\x0e\x32\x17.tensorboard.FullTypeId\x12&\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x18.tensorboard.FullTypeDef\x12\x0b\n\x01s\x18\x03 \x01(\tH\x00\x12\x0b\n\x01i\x18\x04 \x01(\x03H\x00\x42\x06\n\x04\x61ttr*\xda\x04\n\nFullTypeId\x12\r\n\tTFT_UNSET\x10\x00\x12\x0b\n\x07TFT_VAR\x10\x01\x12\x0b\n\x07TFT_ANY\x10\x02\x12\x0f\n\x0bTFT_PRODUCT\x10\x03\x12\r\n\tTFT_NAMED\x10\x04\x12\x10\n\x0cTFT_FOR_EACH\x10\x14\x12\x10\n\x0cTFT_CALLABLE\x10\x64\x12\x0f\n\nTFT_TENSOR\x10\xe8\x07\x12\x0e\n\tTFT_ARRAY\x10\xe9\x07\x12\x11\n\x0cTFT_OPTIONAL\x10\xea\x07\x12\x10\n\x0bTFT_LITERAL\x10\xeb\x07\x12\x10\n\x0bTFT_ENCODED\x10\xec\x07\x12\x15\n\x10TFT_SHAPE_TENSOR\x10\xed\x07\x12\r\n\x08TFT_BOOL\x10\xc8\x01\x12\x0e\n\tTFT_UINT8\x10\xc9\x01\x12\x0f\n\nTFT_UINT16\x10\xca\x01\x12\x0f\n\nTFT_UINT32\x10\xcb\x01\x12\x0f\n\nTFT_UINT64\x10\xcc\x01\x12\r\n\x08TFT_INT8\x10\xcd\x01\x12\x0e\n\tTFT_INT16\x10\xce\x01\x12\x0e\n\tTFT_INT32\x10\xcf\x01\x12\x0e\n\tTFT_INT64\x10\xd0\x01\x12\r\n\x08TFT_HALF\x10\xd1\x01\x12\x0e\n\tTFT_FLOAT\x10\xd2\x01\x12\x0f\n\nTFT_DOUBLE\x10\xd3\x01\x12\x11\n\x0cTFT_BFLOAT16\x10\xd7\x01\x12\x12\n\rTFT_COMPLEX64\x10\xd4\x01\x12\x13\n\x0eTFT_COMPLEX128\x10\xd5\x01\x12\x0f\n\nTFT_STRING\x10\xd6\x01\x12\x10\n\x0bTFT_DATASET\x10\xf6N\x12\x0f\n\nTFT_RAGGED\x10\xf7N\x12\x11\n\x0cTFT_ITERATOR\x10\xf8N\x12\x13\n\x0eTFT_MUTEX_LOCK\x10\xdaO\x12\x17\n\x12TFT_LEGACY_VARIANT\x10\xdbOB\x81\x01\n\x18org.tensorflow.frameworkB\x0e\x46ullTypeProtosP\x01ZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/full_type_go_proto\xf8\x01\x01\x62\x06proto3')

_FULLTYPEID = DESCRIPTOR.enum_types_by_name['FullTypeId']
FullTypeId = enum_type_wrapper.EnumTypeWrapper(_FULLTYPEID)
TFT_UNSET = 0
TFT_VAR = 1
TFT_ANY = 2
TFT_PRODUCT = 3
TFT_NAMED = 4
TFT_FOR_EACH = 20
TFT_CALLABLE = 100
TFT_TENSOR = 1000
TFT_ARRAY = 1001
TFT_OPTIONAL = 1002
TFT_LITERAL = 1003
TFT_ENCODED = 1004
TFT_SHAPE_TENSOR = 1005
TFT_BOOL = 200
TFT_UINT8 = 201
TFT_UINT16 = 202
TFT_UINT32 = 203
TFT_UINT64 = 204
TFT_INT8 = 205
TFT_INT16 = 206
TFT_INT32 = 207
TFT_INT64 = 208
TFT_HALF = 209
TFT_FLOAT = 210
TFT_DOUBLE = 211
TFT_BFLOAT16 = 215
TFT_COMPLEX64 = 212
TFT_COMPLEX128 = 213
TFT_STRING = 214
TFT_DATASET = 10102
TFT_RAGGED = 10103
TFT_ITERATOR = 10104
TFT_MUTEX_LOCK = 10202
TFT_LEGACY_VARIANT = 10203


_FULLTYPEDEF = DESCRIPTOR.message_types_by_name['FullTypeDef']
FullTypeDef = _reflection.GeneratedProtocolMessageType('FullTypeDef', (_message.Message,), {
  'DESCRIPTOR' : _FULLTYPEDEF,
  '__module__' : 'tensorboard.compat.proto.full_type_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.FullTypeDef)
  })
_sym_db.RegisterMessage(FullTypeDef)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\016FullTypeProtosP\001ZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/full_type_go_proto\370\001\001'
  _FULLTYPEID._serialized_start=190
  _FULLTYPEID._serialized_end=792
  _FULLTYPEDEF._serialized_start=58
  _FULLTYPEDEF._serialized_end=187
# @@protoc_insertion_point(module_scope)



# Copyright 2019 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""TensorBoard 3D mesh visualizer plugin."""

import numpy as np
from werkzeug import wrappers

from tensorboard.backend import http_util
from tensorboard.data import provider
from tensorboard.plugins import base_plugin
from tensorboard.plugins.mesh import metadata
from tensorboard.plugins.mesh import plugin_data_pb2
from tensorboard import plugin_util

_DEFAULT_DOWNSAMPLING = 100  # meshes per time series


class MeshPlugin(base_plugin.TBPlugin):
    """A plugin that serves 3D visualization of meshes."""

    plugin_name = metadata.PLUGIN_NAME

    def __init__(self, context):
        """Instantiates a MeshPlugin via TensorBoard core.

        Args:
          context: A base_plugin.TBContext instance. A magic container that
            TensorBoard uses to make objects available to the plugin.
        """
        self._data_provider = context.data_provider
        self._downsample_to = (context.sampling_hints or {}).get(
            self.plugin_name, _DEFAULT_DOWNSAMPLING
        )
        self._version_checker = plugin_util._MetadataVersionChecker(
            data_kind="mesh",
            latest_known_version=0,
        )

    def _instance_tag_metadata(self, ctx, experiment, run, instance_tag):
        """Gets the `MeshPluginData` proto for an instance tag."""
        results = self._data_provider.list_tensors(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME,
            run_tag_filter=provider.RunTagFilter(
                runs=[run], tags=[instance_tag]
            ),
        )
        content = results[run][instance_tag].plugin_content
        return metadata.parse_plugin_metadata(content)

    def _tag(self, ctx, experiment, run, instance_tag):
        """Gets the user-facing tag name for an instance tag."""
        return self._instance_tag_metadata(
            ctx, experiment, run, instance_tag
        ).name

    def _instance_tags(self, ctx, experiment, run, tag):
        """Gets the instance tag names for a user-facing tag."""
        index = self._data_provider.list_tensors(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME,
            run_tag_filter=provider.RunTagFilter(runs=[run]),
        )
        return [
            instance_tag
            for (instance_tag, ts) in index.get(run, {}).items()
            if tag == metadata.parse_plugin_metadata(ts.plugin_content).name
        ]

    @wrappers.Request.application
    def _serve_tags(self, request):
        """A route (HTTP handler) that returns a response with tags.

        Args:
          request: The werkzeug.Request object.

        Returns:
          A response that contains a JSON object. The keys of the object
          are all the runs. Each run is mapped to a (potentially empty)
          list of all tags that are relevant to this plugin.
        """
        ctx = plugin_util.context(request.environ)
        experiment = plugin_util.experiment_id(request.environ)
        all_runs = self._data_provider.list_tensors(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME,
        )

        # tagToContent is itself a dictionary mapping tag name to string
        # SummaryMetadata.plugin_data.content. Retrieve the keys of that dictionary
        # to obtain a list of tags associated with each run. For each tag estimate
        # number of samples.
        response = dict()
        for run, tags in all_runs.items():
            response[run] = dict()
            for instance_tag, metadatum in tags.items():
                md = metadata.parse_plugin_metadata(metadatum.plugin_content)
                if not self._version_checker.ok(md.version, run, instance_tag):
                    continue
                # Make sure we only operate on user-defined tags here.
                tag = self._tag(ctx, experiment, run, instance_tag)
                meta = self._instance_tag_metadata(
                    ctx, experiment, run, instance_tag
                )
                # Batch size must be defined, otherwise we don't know how many
                # samples were there.
                response[run][tag] = {"samples": meta.shape[0]}
        return http_util.Respond(request, response, "application/json")

    def get_plugin_apps(self):
        """Gets all routes offered by the plugin.

        This method is called by TensorBoard when retrieving all the
        routes offered by the plugin.

        Returns:
          A dictionary mapping URL path to route that handles it.
        """
        # Note that the methods handling routes are decorated with
        # @wrappers.Request.application.
        return {
            "/tags": self._serve_tags,
            "/meshes": self._serve_mesh_metadata,
            "/data": self._serve_mesh_data,
        }

    def is_active(self):
        return False  # `list_plugins` as called by TB core suffices

    def frontend_metadata(self):
        return base_plugin.FrontendMetadata(element_name="mesh-dashboard")

    def _get_sample(self, tensor_datum, sample):
        """Returns a single sample from a batch of samples."""
        return tensor_datum.numpy[sample].tolist()

    def _get_tensor_metadata(
        self, event, content_type, components, data_shape, config
    ):
        """Converts a TensorDatum into a JSON-compatible response.

        Args:
          event: TensorDatum object containing data in proto format.
          content_type: enum plugin_data_pb2.MeshPluginData.ContentType value,
            representing content type in TensorDatum.
          components: Bitmask representing all parts (vertices, colors, etc.) that
            belong to the summary.
          data_shape: list of dimensions sizes of the tensor.
          config: rendering scene configuration as dictionary.

        Returns:
          Dictionary of transformed metadata.
        """
        return {
            "wall_time": event.wall_time,
            "step": event.step,
            "content_type": content_type,
            "components": components,
            "config": config,
            "data_shape": list(data_shape),
        }

    def _get_tensor_data(self, event, sample):
        """Convert a TensorDatum into a JSON-compatible response."""
        data = self._get_sample(event, sample)
        return data

    def _collect_tensor_events(self, request, step=None):
        """Collects list of tensor events based on request."""
        ctx = plugin_util.context(request.environ)
        experiment = plugin_util.experiment_id(request.environ)
        run = request.args.get("run")
        tag = request.args.get("tag")

        tensor_events = []  # List of tuples (meta, tensor) that contain tag.
        for instance_tag in self._instance_tags(ctx, experiment, run, tag):
            tensors = self._data_provider.read_tensors(
                ctx,
                experiment_id=experiment,
                plugin_name=metadata.PLUGIN_NAME,
                run_tag_filter=provider.RunTagFilter(
                    runs=[run], tags=[instance_tag]
                ),
                downsample=self._downsample_to,
            )[run][instance_tag]
            meta = self._instance_tag_metadata(
                ctx, experiment, run, instance_tag
            )
            tensor_events += [(meta, tensor) for tensor in tensors]

        if step is not None:
            tensor_events = [
                event for event in tensor_events if event[1].step == step
            ]
        else:
            # Make sure tensors sorted by step in ascending order.
            tensor_events = sorted(
                tensor_events, key=lambda tensor_data: tensor_data[1].step
            )

        return tensor_events

    @wrappers.Request.application
    def _serve_mesh_data(self, request):
        """A route that returns data for particular summary of specified type.

        Data can represent vertices coordinates, vertices indices in faces,
        vertices colors and so on. Each mesh may have different combination of
        abovementioned data and each type/part of mesh summary must be served as
        separate roundtrip to the server.

        Args:
          request: werkzeug.Request containing content_type as a name of enum
            plugin_data_pb2.MeshPluginData.ContentType.

        Returns:
          werkzeug.Response either float32 or int32 data in binary format.
        """
        step = float(request.args.get("step", 0.0))
        tensor_events = self._collect_tensor_events(request, step)
        content_type = request.args.get("content_type")
        try:
            content_type = plugin_data_pb2.MeshPluginData.ContentType.Value(
                content_type
            )
        except ValueError:
            return http_util.Respond(
                request, "Bad content_type", "text/plain", 400
            )
        sample = int(request.args.get("sample", 0))

        response = [
            self._get_tensor_data(tensor, sample)
            for meta, tensor in tensor_events
            if meta.content_type == content_type
        ]

        np_type = {
            plugin_data_pb2.MeshPluginData.VERTEX: np.float32,
            plugin_data_pb2.MeshPluginData.FACE: np.int32,
            plugin_data_pb2.MeshPluginData.COLOR: np.uint8,
        }[content_type]

        response = np.array(response, dtype=np_type)
        # Looks like reshape can take around 160ms, so why not store it reshaped.
        response = response.reshape(-1).tobytes()

        return http_util.Respond(request, response, "arraybuffer")

    @wrappers.Request.application
    def _serve_mesh_metadata(self, request):
        """A route that returns the mesh metadata associated with a tag.

        Metadata consists of wall time, type of elements in tensor, scene
        configuration and so on.

        Args:
          request: The werkzeug.Request object.

        Returns:
          A JSON list of mesh data associated with the run and tag
          combination.
        """
        tensor_events = self._collect_tensor_events(request)

        # We convert the tensor data to text.
        response = [
            self._get_tensor_metadata(
                tensor,
                meta.content_type,
                meta.components,
                meta.shape,
                meta.json_config,
            )
            for meta, tensor in tensor_events
        ]
        return http_util.Respond(request, response, "application/json")



# Copyright 2017 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""The TensorBoard Graphs plugin."""


import json
from werkzeug import wrappers

from tensorboard import errors
from tensorboard import plugin_util
from tensorboard.backend import http_util
from tensorboard.backend import process_graph
from tensorboard.compat.proto import config_pb2
from tensorboard.compat.proto import graph_pb2
from tensorboard.data import provider
from tensorboard.plugins import base_plugin
from tensorboard.plugins.graph import graph_util
from tensorboard.plugins.graph import keras_util
from tensorboard.plugins.graph import metadata
from tensorboard.util import tb_logging

logger = tb_logging.get_logger()


class GraphsPlugin(base_plugin.TBPlugin):
    """Graphs Plugin for TensorBoard."""

    plugin_name = metadata.PLUGIN_NAME

    def __init__(self, context):
        """Instantiates GraphsPlugin via TensorBoard core.

        Args:
          context: A base_plugin.TBContext instance.
        """
        self._data_provider = context.data_provider

    def get_plugin_apps(self):
        return {
            "/graph": self.graph_route,
            "/info": self.info_route,
            "/run_metadata": self.run_metadata_route,
        }

    def is_active(self):
        """The graphs plugin is active iff any run has a graph or metadata."""
        return False  # `list_plugins` as called by TB core suffices

    def data_plugin_names(self):
        return (
            metadata.PLUGIN_NAME,
            metadata.PLUGIN_NAME_RUN_METADATA,
            metadata.PLUGIN_NAME_RUN_METADATA_WITH_GRAPH,
            metadata.PLUGIN_NAME_KERAS_MODEL,
            metadata.PLUGIN_NAME_TAGGED_RUN_METADATA,
        )

    def frontend_metadata(self):
        return base_plugin.FrontendMetadata(
            element_name="tf-graph-dashboard",
            # TODO(@chihuahua): Reconcile this setting with Health Pills.
            disable_reload=True,
        )

    def info_impl(self, ctx, experiment=None):
        """Returns a dict of all runs and their data availabilities."""
        result = {}

        def add_row_item(run, tag=None):
            run_item = result.setdefault(
                run,
                {
                    "run": run,
                    "tags": {},
                    # A run-wide GraphDef of ops.
                    "run_graph": False,
                },
            )

            tag_item = None
            if tag:
                tag_item = run_item.get("tags").setdefault(
                    tag,
                    {
                        "tag": tag,
                        "conceptual_graph": False,
                        # A tagged GraphDef of ops.
                        "op_graph": False,
                        "profile": False,
                    },
                )
            return (run_item, tag_item)

        mapping = self._data_provider.list_blob_sequences(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME_RUN_METADATA_WITH_GRAPH,
        )
        for run_name, tags in mapping.items():
            for tag, tag_data in tags.items():
                # The Summary op is defined in TensorFlow and does not use a stringified proto
                # as a content of plugin data. It contains single string that denotes a version.
                # https://github.com/tensorflow/tensorflow/blob/11f4ecb54708865ec757ca64e4805957b05d7570/tensorflow/python/ops/summary_ops_v2.py#L789-L790
                if tag_data.plugin_content != b"1":
                    logger.warning(
                        "Ignoring unrecognizable version of RunMetadata."
                    )
                    continue
                (_, tag_item) = add_row_item(run_name, tag)
                tag_item["op_graph"] = True

        # Tensors associated with plugin name metadata.PLUGIN_NAME_RUN_METADATA
        # contain both op graph and profile information.
        mapping = self._data_provider.list_blob_sequences(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME_RUN_METADATA,
        )
        for run_name, tags in mapping.items():
            for tag, tag_data in tags.items():
                if tag_data.plugin_content != b"1":
                    logger.warning(
                        "Ignoring unrecognizable version of RunMetadata."
                    )
                    continue
                (_, tag_item) = add_row_item(run_name, tag)
                tag_item["profile"] = True
                tag_item["op_graph"] = True

        # Tensors associated with plugin name metadata.PLUGIN_NAME_KERAS_MODEL
        # contain serialized Keras model in JSON format.
        mapping = self._data_provider.list_blob_sequences(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME_KERAS_MODEL,
        )
        for run_name, tags in mapping.items():
            for tag, tag_data in tags.items():
                if tag_data.plugin_content != b"1":
                    logger.warning(
                        "Ignoring unrecognizable version of RunMetadata."
                    )
                    continue
                (_, tag_item) = add_row_item(run_name, tag)
                tag_item["conceptual_graph"] = True

        mapping = self._data_provider.list_blob_sequences(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME,
        )
        for run_name, tags in mapping.items():
            if metadata.RUN_GRAPH_NAME in tags:
                (run_item, _) = add_row_item(run_name, None)
                run_item["run_graph"] = True

        # Top level `Event.tagged_run_metadata` represents profile data only.
        mapping = self._data_provider.list_blob_sequences(
            ctx,
            experiment_id=experiment,
            plugin_name=metadata.PLUGIN_NAME_TAGGED_RUN_METADATA,
        )
        for run_name, tags in mapping.items():
            for tag in tags:
                (_, tag_item) = add_row_item(run_name, tag)
                tag_item["profile"] = True

        return result

    def _read_blob(self, ctx, experiment, plugin_names, run, tag):
        for plugin_name in plugin_names:
            blob_sequences = self._data_provider.read_blob_sequences(
                ctx,
                experiment_id=experiment,
                plugin_name=plugin_name,
                run_tag_filter=provider.RunTagFilter(runs=[run], tags=[tag]),
                downsample=1,
            )
            blob_sequence_data = blob_sequences.get(run, {}).get(tag, ())
            try:
                blob_ref = blob_sequence_data[0].values[0]
            except IndexError:
                continue
            return self._data_provider.read_blob(
                ctx, blob_key=blob_ref.blob_key
            )
        raise errors.NotFoundError()

    def graph_impl(
        self,
        ctx,
        run,
        tag,
        is_conceptual,
        experiment=None,
        limit_attr_size=None,
        large_attrs_key=None,
    ):
        """Result of the form `(body, mime_type)`; may raise `NotFound`."""
        if is_conceptual:
            keras_model_config = json.loads(
                self._read_blob(
                    ctx,
                    experiment,
                    [metadata.PLUGIN_NAME_KERAS_MODEL],
                    run,
                    tag,
                )
            )
            graph = keras_util.keras_model_to_graph_def(keras_model_config)

        elif tag is None:
            graph_raw = self._read_blob(
                ctx,
                experiment,
                [metadata.PLUGIN_NAME],
                run,
                metadata.RUN_GRAPH_NAME,
            )
            graph = graph_pb2.GraphDef.FromString(graph_raw)

        else:
            # Op graph: could be either of two plugins. (Cf. `info_impl`.)
            plugins = [
                metadata.PLUGIN_NAME_RUN_METADATA,
                metadata.PLUGIN_NAME_RUN_METADATA_WITH_GRAPH,
            ]
            raw_run_metadata = self._read_blob(
                ctx, experiment, plugins, run, tag
            )
            run_metadata = config_pb2.RunMetadata.FromString(raw_run_metadata)
            graph = graph_util.merge_graph_defs(
                [
                    func_graph.pre_optimization_graph
                    for func_graph in run_metadata.function_graphs
                ]
            )

        # This next line might raise a ValueError if the limit parameters
        # are invalid (size is negative, size present but key absent, etc.).
        process_graph.prepare_graph_for_ui(
            graph, limit_attr_size, large_attrs_key
        )
        return (str(graph), "text/x-protobuf")  # pbtxt

    def run_metadata_impl(self, ctx, experiment, run, tag):
        """Result of the form `(body, mime_type)`; may raise `NotFound`."""
        # Profile graph: could be either of two plugins. (Cf. `info_impl`.)
        plugins = [
            metadata.PLUGIN_NAME_TAGGED_RUN_METADATA,
            metadata.PLUGIN_NAME_RUN_METADATA,
        ]
        raw_run_metadata = self._read_blob(ctx, experiment, plugins, run, tag)
        run_metadata = config_pb2.RunMetadata.FromString(raw_run_metadata)
        return (str(run_metadata), "text/x-protobuf")  # pbtxt

    @wrappers.Request.application
    def info_route(self, request):
        ctx = plugin_util.context(request.environ)
        experiment = plugin_util.experiment_id(request.environ)
        info = self.info_impl(ctx, experiment)
        return http_util.Respond(request, info, "application/json")

    @wrappers.Request.application
    def graph_route(self, request):
        """Given a single run, return the graph definition in protobuf
        format."""
        ctx = plugin_util.context(request.environ)
        experiment = plugin_util.experiment_id(request.environ)
        run = request.args.get("run")
        tag = request.args.get("tag")
        conceptual_arg = request.args.get("conceptual", False)
        is_conceptual = True if conceptual_arg == "true" else False

        if run is None:
            return http_util.Respond(
                request, 'query parameter "run" is required', "text/plain", 400
            )

        limit_attr_size = request.args.get("limit_attr_size", None)
        if limit_attr_size is not None:
            try:
                limit_attr_size = int(limit_attr_size)
            except ValueError:
                return http_util.Respond(
                    request,
                    "query parameter `limit_attr_size` must be an integer",
                    "text/plain",
                    400,
                )

        large_attrs_key = request.args.get("large_attrs_key", None)

        try:
            result = self.graph_impl(
                ctx,
                run,
                tag,
                is_conceptual,
                experiment,
                limit_attr_size,
                large_attrs_key,
            )
        except ValueError as e:
            return http_util.Respond(request, e.message, "text/plain", code=400)
        (body, mime_type) = result
        return http_util.Respond(request, body, mime_type)

    @wrappers.Request.application
    def run_metadata_route(self, request):
        """Given a tag and a run, return the session.run() metadata."""
        ctx = plugin_util.context(request.environ)
        experiment = plugin_util.experiment_id(request.environ)
        tag = request.args.get("tag")
        run = request.args.get("run")
        if tag is None:
            return http_util.Respond(
                request, 'query parameter "tag" is required', "text/plain", 400
            )
        if run is None:
            return http_util.Respond(
                request, 'query parameter "run" is required', "text/plain", 400
            )
        (body, mime_type) = self.run_metadata_impl(ctx, experiment, run, tag)
        return http_util.Respond(request, body, mime_type)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/summary.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import histogram_pb2 as tensorboard_dot_compat_dot_proto_dot_histogram__pb2
from tensorboard.compat.proto import tensor_pb2 as tensorboard_dot_compat_dot_proto_dot_tensor__pb2

from tensorboard.compat.proto.histogram_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&tensorboard/compat/proto/summary.proto\x12\x0btensorboard\x1a(tensorboard/compat/proto/histogram.proto\x1a%tensorboard/compat/proto/tensor.proto\"\'\n\x12SummaryDescription\x12\x11\n\ttype_hint\x18\x01 \x01(\t\"\xe2\x01\n\x0fSummaryMetadata\x12<\n\x0bplugin_data\x18\x01 \x01(\x0b\x32\'.tensorboard.SummaryMetadata.PluginData\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x1b\n\x13summary_description\x18\x03 \x01(\t\x12*\n\ndata_class\x18\x04 \x01(\x0e\x32\x16.tensorboard.DataClass\x1a\x32\n\nPluginData\x12\x13\n\x0bplugin_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\xe4\x04\n\x07Summary\x12)\n\x05value\x18\x01 \x03(\x0b\x32\x1a.tensorboard.Summary.Value\x1aX\n\x05Image\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x12\n\ncolorspace\x18\x03 \x01(\x05\x12\x1c\n\x14\x65ncoded_image_string\x18\x04 \x01(\x0c\x1a}\n\x05\x41udio\x12\x13\n\x0bsample_rate\x18\x01 \x01(\x02\x12\x14\n\x0cnum_channels\x18\x02 \x01(\x03\x12\x15\n\rlength_frames\x18\x03 \x01(\x03\x12\x1c\n\x14\x65ncoded_audio_string\x18\x04 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x05 \x01(\t\x1a\xd4\x02\n\x05Value\x12\x11\n\tnode_name\x18\x07 \x01(\t\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12.\n\x08metadata\x18\t \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\x12\x16\n\x0csimple_value\x18\x02 \x01(\x02H\x00\x12&\n\x1cobsolete_old_style_histogram\x18\x03 \x01(\x0cH\x00\x12+\n\x05image\x18\x04 \x01(\x0b\x32\x1a.tensorboard.Summary.ImageH\x00\x12,\n\x05histo\x18\x05 \x01(\x0b\x32\x1b.tensorboard.HistogramProtoH\x00\x12+\n\x05\x61udio\x18\x06 \x01(\x0b\x32\x1a.tensorboard.Summary.AudioH\x00\x12*\n\x06tensor\x18\x08 \x01(\x0b\x32\x18.tensorboard.TensorProtoH\x00\x42\x07\n\x05value*o\n\tDataClass\x12\x16\n\x12\x44\x41TA_CLASS_UNKNOWN\x10\x00\x12\x15\n\x11\x44\x41TA_CLASS_SCALAR\x10\x01\x12\x15\n\x11\x44\x41TA_CLASS_TENSOR\x10\x02\x12\x1c\n\x18\x44\x41TA_CLASS_BLOB_SEQUENCE\x10\x03\x42~\n\x18org.tensorflow.frameworkB\rSummaryProtosP\x01ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/summary_go_proto\xf8\x01\x01P\x00\x62\x06proto3')

_DATACLASS = DESCRIPTOR.enum_types_by_name['DataClass']
DataClass = enum_type_wrapper.EnumTypeWrapper(_DATACLASS)
DATA_CLASS_UNKNOWN = 0
DATA_CLASS_SCALAR = 1
DATA_CLASS_TENSOR = 2
DATA_CLASS_BLOB_SEQUENCE = 3


_SUMMARYDESCRIPTION = DESCRIPTOR.message_types_by_name['SummaryDescription']
_SUMMARYMETADATA = DESCRIPTOR.message_types_by_name['SummaryMetadata']
_SUMMARYMETADATA_PLUGINDATA = _SUMMARYMETADATA.nested_types_by_name['PluginData']
_SUMMARY = DESCRIPTOR.message_types_by_name['Summary']
_SUMMARY_IMAGE = _SUMMARY.nested_types_by_name['Image']
_SUMMARY_AUDIO = _SUMMARY.nested_types_by_name['Audio']
_SUMMARY_VALUE = _SUMMARY.nested_types_by_name['Value']
SummaryDescription = _reflection.GeneratedProtocolMessageType('SummaryDescription', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYDESCRIPTION,
  '__module__' : 'tensorboard.compat.proto.summary_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.SummaryDescription)
  })
_sym_db.RegisterMessage(SummaryDescription)

SummaryMetadata = _reflection.GeneratedProtocolMessageType('SummaryMetadata', (_message.Message,), {

  'PluginData' : _reflection.GeneratedProtocolMessageType('PluginData', (_message.Message,), {
    'DESCRIPTOR' : _SUMMARYMETADATA_PLUGINDATA,
    '__module__' : 'tensorboard.compat.proto.summary_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.SummaryMetadata.PluginData)
    })
  ,
  'DESCRIPTOR' : _SUMMARYMETADATA,
  '__module__' : 'tensorboard.compat.proto.summary_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.SummaryMetadata)
  })
_sym_db.RegisterMessage(SummaryMetadata)
_sym_db.RegisterMessage(SummaryMetadata.PluginData)

Summary = _reflection.GeneratedProtocolMessageType('Summary', (_message.Message,), {

  'Image' : _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
    'DESCRIPTOR' : _SUMMARY_IMAGE,
    '__module__' : 'tensorboard.compat.proto.summary_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.Summary.Image)
    })
  ,

  'Audio' : _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
    'DESCRIPTOR' : _SUMMARY_AUDIO,
    '__module__' : 'tensorboard.compat.proto.summary_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.Summary.Audio)
    })
  ,

  'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
    'DESCRIPTOR' : _SUMMARY_VALUE,
    '__module__' : 'tensorboard.compat.proto.summary_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.Summary.Value)
    })
  ,
  'DESCRIPTOR' : _SUMMARY,
  '__module__' : 'tensorboard.compat.proto.summary_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.Summary)
  })
_sym_db.RegisterMessage(Summary)
_sym_db.RegisterMessage(Summary.Image)
_sym_db.RegisterMessage(Summary.Audio)
_sym_db.RegisterMessage(Summary.Value)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkB\rSummaryProtosP\001ZNgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/summary_go_proto\370\001\001'
  _DATACLASS._serialized_start=1021
  _DATACLASS._serialized_end=1132
  _SUMMARYDESCRIPTION._serialized_start=136
  _SUMMARYDESCRIPTION._serialized_end=175
  _SUMMARYMETADATA._serialized_start=178
  _SUMMARYMETADATA._serialized_end=404
  _SUMMARYMETADATA_PLUGINDATA._serialized_start=354
  _SUMMARYMETADATA_PLUGINDATA._serialized_end=404
  _SUMMARY._serialized_start=407
  _SUMMARY._serialized_end=1019
  _SUMMARY_IMAGE._serialized_start=461
  _SUMMARY_IMAGE._serialized_end=549
  _SUMMARY_AUDIO._serialized_start=551
  _SUMMARY_AUDIO._serialized_end=676
  _SUMMARY_VALUE._serialized_start=679
  _SUMMARY_VALUE._serialized_end=1019
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/tfprof_log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard.compat.proto import attr_value_pb2 as tensorboard_dot_compat_dot_proto_dot_attr__value__pb2
from tensorboard.compat.proto import step_stats_pb2 as tensorboard_dot_compat_dot_proto_dot_step__stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)tensorboard/compat/proto/tfprof_log.proto\x12\x0btensorboard\x1a)tensorboard/compat/proto/attr_value.proto\x1a)tensorboard/compat/proto/step_stats.proto\"\xd9\x01\n\x07\x43odeDef\x12*\n\x06traces\x18\x01 \x03(\x0b\x32\x1a.tensorboard.CodeDef.Trace\x1a\xa1\x01\n\x05Trace\x12\x10\n\x04\x66ile\x18\x01 \x01(\tB\x02\x18\x01\x12\x0f\n\x07\x66ile_id\x18\x06 \x01(\x03\x12\x0e\n\x06lineno\x18\x02 \x01(\x05\x12\x14\n\x08\x66unction\x18\x03 \x01(\tB\x02\x18\x01\x12\x13\n\x0b\x66unction_id\x18\x07 \x01(\x03\x12\x10\n\x04line\x18\x04 \x01(\tB\x02\x18\x01\x12\x0f\n\x07line_id\x18\x08 \x01(\x03\x12\x17\n\x0f\x66unc_start_line\x18\x05 \x01(\x05\"d\n\nOpLogEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfloat_ops\x18\x02 \x01(\x03\x12\r\n\x05types\x18\x03 \x03(\t\x12&\n\x08\x63ode_def\x18\x04 \x01(\x0b\x32\x14.tensorboard.CodeDef\"\xac\x01\n\nOpLogProto\x12,\n\x0blog_entries\x18\x01 \x03(\x0b\x32\x17.tensorboard.OpLogEntry\x12=\n\x0cid_to_string\x18\x02 \x03(\x0b\x32\'.tensorboard.OpLogProto.IdToStringEntry\x1a\x31\n\x0fIdToStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x0cProfileProto\x12\x33\n\x05nodes\x18\x01 \x03(\x0b\x32$.tensorboard.ProfileProto.NodesEntry\x12\x11\n\thas_trace\x18\x02 \x01(\x08\x12\x1f\n\x17miss_accelerator_stream\x18\x05 \x01(\x08\x12\r\n\x05steps\x18\x03 \x03(\x03\x12?\n\x0cid_to_string\x18\x04 \x03(\x0b\x32).tensorboard.ProfileProto.IdToStringEntry\x1a\x46\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.tensorboard.ProfileNode:\x02\x38\x01\x1a\x31\n\x0fIdToStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x08\n\x0bProfileNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02op\x18\t \x01(\t\x12\n\n\x02id\x18\r \x01(\x03\x12\x34\n\x06inputs\x18\x02 \x03(\x0b\x32$.tensorboard.ProfileNode.InputsEntry\x12?\n\x0cinput_shapes\x18\x10 \x03(\x0b\x32).tensorboard.ProfileNode.InputShapesEntry\x12\x36\n\x07outputs\x18\x03 \x03(\x0b\x32%.tensorboard.ProfileNode.OutputsEntry\x12\x41\n\routput_shapes\x18\x0f \x03(\x0b\x32*.tensorboard.ProfileNode.OutputShapesEntry\x12\x46\n\x10src_output_index\x18\x0e \x03(\x0b\x32,.tensorboard.ProfileNode.SrcOutputIndexEntry\x12\r\n\x05shape\x18\x04 \x03(\x03\x12\x10\n\x08op_types\x18\x05 \x03(\t\x12\x18\n\x10\x63\x61nonical_device\x18\x06 \x01(\t\x12\x13\n\x0bhost_device\x18\x07 \x01(\t\x12\x11\n\tfloat_ops\x18\x08 \x01(\x03\x12#\n\x05trace\x18\n \x01(\x0b\x32\x14.tensorboard.CodeDef\x12\x32\n\x05\x61ttrs\x18\x0b \x03(\x0b\x32#.tensorboard.ProfileNode.AttrsEntry\x12\x32\n\x05\x65xecs\x18\x0c \x03(\x0b\x32#.tensorboard.ProfileNode.ExecsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x46\n\x10InputShapesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.tensorboard.Tuple:\x02\x38\x01\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1aG\n\x11OutputShapesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.tensorboard.Tuple:\x02\x38\x01\x1a\x35\n\x13SrcOutputIndexEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x44\n\nAttrsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.tensorboard.AttrValue:\x02\x38\x01\x1a\x46\n\nExecsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.tensorboard.ExecProfile:\x02\x38\x01\"\xe7\x03\n\x0b\x45xecProfile\x12\x11\n\trun_count\x18\x01 \x01(\x03\x12\x18\n\x10\x61ll_start_micros\x18\x02 \x01(\x03\x12\x19\n\x11latest_end_micros\x18\x03 \x01(\x03\x12I\n\x11\x61\x63\x63\x65lerator_execs\x18\x04 \x03(\x0b\x32..tensorboard.ExecProfile.AcceleratorExecsEntry\x12\x39\n\tcpu_execs\x18\x05 \x03(\x0b\x32&.tensorboard.ExecProfile.CpuExecsEntry\x12-\n\x0cmemory_execs\x18\x07 \x03(\x0b\x32\x17.tensorboard.ExecMemory\x12\x32\n\x0b\x61llocations\x18\x0b \x03(\x0b\x32\x1d.tensorboard.AllocationRecord\x12\x0f\n\x07\x64\x65vices\x18\x06 \x03(\t\x1aN\n\x15\x41\x63\x63\x65leratorExecsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.tensorboard.ExecTime:\x02\x38\x01\x1a\x46\n\rCpuExecsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.tensorboard.ExecTime:\x02\x38\x01\"-\n\x08\x45xecTime\x12!\n\x05times\x18\x01 \x03(\x0b\x32\x12.tensorboard.Tuple\"\xa8\x03\n\nExecMemory\x12\x15\n\rmemory_micros\x18\x01 \x01(\x03\x12\x17\n\x0fhost_temp_bytes\x18\x02 \x01(\x03\x12\x1d\n\x15host_persistent_bytes\x18\x03 \x01(\x03\x12\x1e\n\x16\x61\x63\x63\x65lerator_temp_bytes\x18\x04 \x01(\x03\x12$\n\x1c\x61\x63\x63\x65lerator_persistent_bytes\x18\x05 \x01(\x03\x12\x17\n\x0frequested_bytes\x18\x06 \x01(\x03\x12\x12\n\npeak_bytes\x18\x07 \x01(\x03\x12\x16\n\x0eresidual_bytes\x18\x08 \x01(\x03\x12\x14\n\x0coutput_bytes\x18\t \x01(\x03\x12\x1e\n\x16\x61llocator_bytes_in_use\x18\n \x01(\x03\x12@\n\routput_memory\x18\x0b \x03(\x0b\x32).tensorboard.ExecMemory.OutputMemoryEntry\x1aH\n\x11OutputMemoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.tensorboard.Memory:\x02\x38\x01\"\x1d\n\x05Tuple\x12\x14\n\x0cint64_values\x18\x01 \x03(\x03\"$\n\x06Memory\x12\r\n\x05\x62ytes\x18\x01 \x01(\x03\x12\x0b\n\x03ptr\x18\x02 \x01(\x04\x42RZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/profiler/protos_all_go_protob\x06proto3')



_CODEDEF = DESCRIPTOR.message_types_by_name['CodeDef']
_CODEDEF_TRACE = _CODEDEF.nested_types_by_name['Trace']
_OPLOGENTRY = DESCRIPTOR.message_types_by_name['OpLogEntry']
_OPLOGPROTO = DESCRIPTOR.message_types_by_name['OpLogProto']
_OPLOGPROTO_IDTOSTRINGENTRY = _OPLOGPROTO.nested_types_by_name['IdToStringEntry']
_PROFILEPROTO = DESCRIPTOR.message_types_by_name['ProfileProto']
_PROFILEPROTO_NODESENTRY = _PROFILEPROTO.nested_types_by_name['NodesEntry']
_PROFILEPROTO_IDTOSTRINGENTRY = _PROFILEPROTO.nested_types_by_name['IdToStringEntry']
_PROFILENODE = DESCRIPTOR.message_types_by_name['ProfileNode']
_PROFILENODE_INPUTSENTRY = _PROFILENODE.nested_types_by_name['InputsEntry']
_PROFILENODE_INPUTSHAPESENTRY = _PROFILENODE.nested_types_by_name['InputShapesEntry']
_PROFILENODE_OUTPUTSENTRY = _PROFILENODE.nested_types_by_name['OutputsEntry']
_PROFILENODE_OUTPUTSHAPESENTRY = _PROFILENODE.nested_types_by_name['OutputShapesEntry']
_PROFILENODE_SRCOUTPUTINDEXENTRY = _PROFILENODE.nested_types_by_name['SrcOutputIndexEntry']
_PROFILENODE_ATTRSENTRY = _PROFILENODE.nested_types_by_name['AttrsEntry']
_PROFILENODE_EXECSENTRY = _PROFILENODE.nested_types_by_name['ExecsEntry']
_EXECPROFILE = DESCRIPTOR.message_types_by_name['ExecProfile']
_EXECPROFILE_ACCELERATOREXECSENTRY = _EXECPROFILE.nested_types_by_name['AcceleratorExecsEntry']
_EXECPROFILE_CPUEXECSENTRY = _EXECPROFILE.nested_types_by_name['CpuExecsEntry']
_EXECTIME = DESCRIPTOR.message_types_by_name['ExecTime']
_EXECMEMORY = DESCRIPTOR.message_types_by_name['ExecMemory']
_EXECMEMORY_OUTPUTMEMORYENTRY = _EXECMEMORY.nested_types_by_name['OutputMemoryEntry']
_TUPLE = DESCRIPTOR.message_types_by_name['Tuple']
_MEMORY = DESCRIPTOR.message_types_by_name['Memory']
CodeDef = _reflection.GeneratedProtocolMessageType('CodeDef', (_message.Message,), {

  'Trace' : _reflection.GeneratedProtocolMessageType('Trace', (_message.Message,), {
    'DESCRIPTOR' : _CODEDEF_TRACE,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.CodeDef.Trace)
    })
  ,
  'DESCRIPTOR' : _CODEDEF,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.CodeDef)
  })
_sym_db.RegisterMessage(CodeDef)
_sym_db.RegisterMessage(CodeDef.Trace)

OpLogEntry = _reflection.GeneratedProtocolMessageType('OpLogEntry', (_message.Message,), {
  'DESCRIPTOR' : _OPLOGENTRY,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.OpLogEntry)
  })
_sym_db.RegisterMessage(OpLogEntry)

OpLogProto = _reflection.GeneratedProtocolMessageType('OpLogProto', (_message.Message,), {

  'IdToStringEntry' : _reflection.GeneratedProtocolMessageType('IdToStringEntry', (_message.Message,), {
    'DESCRIPTOR' : _OPLOGPROTO_IDTOSTRINGENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.OpLogProto.IdToStringEntry)
    })
  ,
  'DESCRIPTOR' : _OPLOGPROTO,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.OpLogProto)
  })
_sym_db.RegisterMessage(OpLogProto)
_sym_db.RegisterMessage(OpLogProto.IdToStringEntry)

ProfileProto = _reflection.GeneratedProtocolMessageType('ProfileProto', (_message.Message,), {

  'NodesEntry' : _reflection.GeneratedProtocolMessageType('NodesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILEPROTO_NODESENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileProto.NodesEntry)
    })
  ,

  'IdToStringEntry' : _reflection.GeneratedProtocolMessageType('IdToStringEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILEPROTO_IDTOSTRINGENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileProto.IdToStringEntry)
    })
  ,
  'DESCRIPTOR' : _PROFILEPROTO,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ProfileProto)
  })
_sym_db.RegisterMessage(ProfileProto)
_sym_db.RegisterMessage(ProfileProto.NodesEntry)
_sym_db.RegisterMessage(ProfileProto.IdToStringEntry)

ProfileNode = _reflection.GeneratedProtocolMessageType('ProfileNode', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_INPUTSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.InputsEntry)
    })
  ,

  'InputShapesEntry' : _reflection.GeneratedProtocolMessageType('InputShapesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_INPUTSHAPESENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.InputShapesEntry)
    })
  ,

  'OutputsEntry' : _reflection.GeneratedProtocolMessageType('OutputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_OUTPUTSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.OutputsEntry)
    })
  ,

  'OutputShapesEntry' : _reflection.GeneratedProtocolMessageType('OutputShapesEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_OUTPUTSHAPESENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.OutputShapesEntry)
    })
  ,

  'SrcOutputIndexEntry' : _reflection.GeneratedProtocolMessageType('SrcOutputIndexEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_SRCOUTPUTINDEXENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.SrcOutputIndexEntry)
    })
  ,

  'AttrsEntry' : _reflection.GeneratedProtocolMessageType('AttrsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_ATTRSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.AttrsEntry)
    })
  ,

  'ExecsEntry' : _reflection.GeneratedProtocolMessageType('ExecsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROFILENODE_EXECSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode.ExecsEntry)
    })
  ,
  'DESCRIPTOR' : _PROFILENODE,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ProfileNode)
  })
_sym_db.RegisterMessage(ProfileNode)
_sym_db.RegisterMessage(ProfileNode.InputsEntry)
_sym_db.RegisterMessage(ProfileNode.InputShapesEntry)
_sym_db.RegisterMessage(ProfileNode.OutputsEntry)
_sym_db.RegisterMessage(ProfileNode.OutputShapesEntry)
_sym_db.RegisterMessage(ProfileNode.SrcOutputIndexEntry)
_sym_db.RegisterMessage(ProfileNode.AttrsEntry)
_sym_db.RegisterMessage(ProfileNode.ExecsEntry)

ExecProfile = _reflection.GeneratedProtocolMessageType('ExecProfile', (_message.Message,), {

  'AcceleratorExecsEntry' : _reflection.GeneratedProtocolMessageType('AcceleratorExecsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECPROFILE_ACCELERATOREXECSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ExecProfile.AcceleratorExecsEntry)
    })
  ,

  'CpuExecsEntry' : _reflection.GeneratedProtocolMessageType('CpuExecsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECPROFILE_CPUEXECSENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ExecProfile.CpuExecsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECPROFILE,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ExecProfile)
  })
_sym_db.RegisterMessage(ExecProfile)
_sym_db.RegisterMessage(ExecProfile.AcceleratorExecsEntry)
_sym_db.RegisterMessage(ExecProfile.CpuExecsEntry)

ExecTime = _reflection.GeneratedProtocolMessageType('ExecTime', (_message.Message,), {
  'DESCRIPTOR' : _EXECTIME,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ExecTime)
  })
_sym_db.RegisterMessage(ExecTime)

ExecMemory = _reflection.GeneratedProtocolMessageType('ExecMemory', (_message.Message,), {

  'OutputMemoryEntry' : _reflection.GeneratedProtocolMessageType('OutputMemoryEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECMEMORY_OUTPUTMEMORYENTRY,
    '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.ExecMemory.OutputMemoryEntry)
    })
  ,
  'DESCRIPTOR' : _EXECMEMORY,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.ExecMemory)
  })
_sym_db.RegisterMessage(ExecMemory)
_sym_db.RegisterMessage(ExecMemory.OutputMemoryEntry)

Tuple = _reflection.GeneratedProtocolMessageType('Tuple', (_message.Message,), {
  'DESCRIPTOR' : _TUPLE,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.Tuple)
  })
_sym_db.RegisterMessage(Tuple)

Memory = _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
  'DESCRIPTOR' : _MEMORY,
  '__module__' : 'tensorboard.compat.proto.tfprof_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.Memory)
  })
_sym_db.RegisterMessage(Memory)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/tensorflow/tensorflow/tensorflow/go/core/profiler/protos_all_go_proto'
  _CODEDEF_TRACE.fields_by_name['file']._options = None
  _CODEDEF_TRACE.fields_by_name['file']._serialized_options = b'\030\001'
  _CODEDEF_TRACE.fields_by_name['function']._options = None
  _CODEDEF_TRACE.fields_by_name['function']._serialized_options = b'\030\001'
  _CODEDEF_TRACE.fields_by_name['line']._options = None
  _CODEDEF_TRACE.fields_by_name['line']._serialized_options = b'\030\001'
  _OPLOGPROTO_IDTOSTRINGENTRY._options = None
  _OPLOGPROTO_IDTOSTRINGENTRY._serialized_options = b'8\001'
  _PROFILEPROTO_NODESENTRY._options = None
  _PROFILEPROTO_NODESENTRY._serialized_options = b'8\001'
  _PROFILEPROTO_IDTOSTRINGENTRY._options = None
  _PROFILEPROTO_IDTOSTRINGENTRY._serialized_options = b'8\001'
  _PROFILENODE_INPUTSENTRY._options = None
  _PROFILENODE_INPUTSENTRY._serialized_options = b'8\001'
  _PROFILENODE_INPUTSHAPESENTRY._options = None
  _PROFILENODE_INPUTSHAPESENTRY._serialized_options = b'8\001'
  _PROFILENODE_OUTPUTSENTRY._options = None
  _PROFILENODE_OUTPUTSENTRY._serialized_options = b'8\001'
  _PROFILENODE_OUTPUTSHAPESENTRY._options = None
  _PROFILENODE_OUTPUTSHAPESENTRY._serialized_options = b'8\001'
  _PROFILENODE_SRCOUTPUTINDEXENTRY._options = None
  _PROFILENODE_SRCOUTPUTINDEXENTRY._serialized_options = b'8\001'
  _PROFILENODE_ATTRSENTRY._options = None
  _PROFILENODE_ATTRSENTRY._serialized_options = b'8\001'
  _PROFILENODE_EXECSENTRY._options = None
  _PROFILENODE_EXECSENTRY._serialized_options = b'8\001'
  _EXECPROFILE_ACCELERATOREXECSENTRY._options = None
  _EXECPROFILE_ACCELERATOREXECSENTRY._serialized_options = b'8\001'
  _EXECPROFILE_CPUEXECSENTRY._options = None
  _EXECPROFILE_CPUEXECSENTRY._serialized_options = b'8\001'
  _EXECMEMORY_OUTPUTMEMORYENTRY._options = None
  _EXECMEMORY_OUTPUTMEMORYENTRY._serialized_options = b'8\001'
  _CODEDEF._serialized_start=145
  _CODEDEF._serialized_end=362
  _CODEDEF_TRACE._serialized_start=201
  _CODEDEF_TRACE._serialized_end=362
  _OPLOGENTRY._serialized_start=364
  _OPLOGENTRY._serialized_end=464
  _OPLOGPROTO._serialized_start=467
  _OPLOGPROTO._serialized_end=639
  _OPLOGPROTO_IDTOSTRINGENTRY._serialized_start=590
  _OPLOGPROTO_IDTOSTRINGENTRY._serialized_end=639
  _PROFILEPROTO._serialized_start=642
  _PROFILEPROTO._serialized_end=964
  _PROFILEPROTO_NODESENTRY._serialized_start=843
  _PROFILEPROTO_NODESENTRY._serialized_end=913
  _PROFILEPROTO_IDTOSTRINGENTRY._serialized_start=590
  _PROFILEPROTO_IDTOSTRINGENTRY._serialized_end=639
  _PROFILENODE._serialized_start=967
  _PROFILENODE._serialized_end=2009
  _PROFILENODE_INPUTSENTRY._serialized_start=1574
  _PROFILENODE_INPUTSENTRY._serialized_end=1619
  _PROFILENODE_INPUTSHAPESENTRY._serialized_start=1621
  _PROFILENODE_INPUTSHAPESENTRY._serialized_end=1691
  _PROFILENODE_OUTPUTSENTRY._serialized_start=1693
  _PROFILENODE_OUTPUTSENTRY._serialized_end=1739
  _PROFILENODE_OUTPUTSHAPESENTRY._serialized_start=1741
  _PROFILENODE_OUTPUTSHAPESENTRY._serialized_end=1812
  _PROFILENODE_SRCOUTPUTINDEXENTRY._serialized_start=1814
  _PROFILENODE_SRCOUTPUTINDEXENTRY._serialized_end=1867
  _PROFILENODE_ATTRSENTRY._serialized_start=1869
  _PROFILENODE_ATTRSENTRY._serialized_end=1937
  _PROFILENODE_EXECSENTRY._serialized_start=1939
  _PROFILENODE_EXECSENTRY._serialized_end=2009
  _EXECPROFILE._serialized_start=2012
  _EXECPROFILE._serialized_end=2499
  _EXECPROFILE_ACCELERATOREXECSENTRY._serialized_start=2349
  _EXECPROFILE_ACCELERATOREXECSENTRY._serialized_end=2427
  _EXECPROFILE_CPUEXECSENTRY._serialized_start=2429
  _EXECPROFILE_CPUEXECSENTRY._serialized_end=2499
  _EXECTIME._serialized_start=2501
  _EXECTIME._serialized_end=2546
  _EXECMEMORY._serialized_start=2549
  _EXECMEMORY._serialized_end=2973
  _EXECMEMORY_OUTPUTMEMORYENTRY._serialized_start=2901
  _EXECMEMORY_OUTPUTMEMORYENTRY._serialized_end=2973
  _TUPLE._serialized_start=2975
  _TUPLE._serialized_end=3004
  _MEMORY._serialized_start=3006
  _MEMORY._serialized_end=3042
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/compat/proto/histogram.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(tensorboard/compat/proto/histogram.proto\x12\x0btensorboard\"\x87\x01\n\x0eHistogramProto\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x0b\n\x03num\x18\x03 \x01(\x01\x12\x0b\n\x03sum\x18\x04 \x01(\x01\x12\x13\n\x0bsum_squares\x18\x05 \x01(\x01\x12\x18\n\x0c\x62ucket_limit\x18\x06 \x03(\x01\x42\x02\x10\x01\x12\x12\n\x06\x62ucket\x18\x07 \x03(\x01\x42\x02\x10\x01\x42\\\n\x18org.tensorflow.frameworkP\x01Z;github.com/google/tsl/tsl/go/core/protobuf/summary_go_proto\xf8\x01\x01\x62\x06proto3')



_HISTOGRAMPROTO = DESCRIPTOR.message_types_by_name['HistogramProto']
HistogramProto = _reflection.GeneratedProtocolMessageType('HistogramProto', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAMPROTO,
  '__module__' : 'tensorboard.compat.proto.histogram_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.HistogramProto)
  })
_sym_db.RegisterMessage(HistogramProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030org.tensorflow.frameworkP\001Z;github.com/google/tsl/tsl/go/core/protobuf/summary_go_proto\370\001\001'
  _HISTOGRAMPROTO.fields_by_name['bucket_limit']._options = None
  _HISTOGRAMPROTO.fields_by_name['bucket_limit']._serialized_options = b'\020\001'
  _HISTOGRAMPROTO.fields_by_name['bucket']._options = None
  _HISTOGRAMPROTO.fields_by_name['bucket']._serialized_options = b'\020\001'
  _HISTOGRAMPROTO._serialized_start=58
  _HISTOGRAMPROTO._serialized_end=193
# @@protoc_insertion_point(module_scope)
